@@ -5,6 +5,7 @@
 #include "sse-check.h"
 
 extern float sqrtf (float);
+extern float fabsf (float);
 
 #define N 8
 
@@ -27,7 +28,7 @@ sse_test (void)
   /* check results:  */
   for (i = 0; i < N; i++)
     {
-      if (r[i] != rc[i])
+      if (fabsf (r[i] - rc[i]) > 0.0001)
 	abort();
     }   
 }
